<?php
/**
 * @version    4.1.2
 * @package    Com_AllVideoShare
 * @author     Vinoth Kumar <admin@mrvinoth.com>
 * @copyright  Copyright (c) 2012 - 2022 Vinoth Kumar. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

defined( '_JEXEC' ) or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Plugin\CMSPlugin;
use MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareYouTubeHelper;

/**
 * Plugin to enable loading videos into content (e.g. articles)
 * This uses the {avsyoutube} syntax
 *
 * @since  4.1.2
 */
class plgContentAllVideoShareYouTube extends CMSPlugin {

	/**
	 * Plugin that loads videos within content
	 *
	 * @param   string   $context   The context of the content being passed to the plugin.
	 * @param   object   &$article  The article object.  Note $article->text is also available
	 * @param   mixed    &$params   The article params
	 * @param   integer  $page      The 'page' number
	 *
	 * @return  void
	 *
	 * @since   4.1.2
	 */
	public function onContentPrepare( $context, &$article, &$params, $page = 0 ) {
		// Don't run this plugin when the content is being indexed
		if ( $context === 'com_finder.indexer' ) {
			return;
		}

		// Simple performance check to determine whether bot should process further
		if ( strpos( $article->text, 'avsyoutube' ) === false ) {
			return;
		}

		// Expression to search for
		$regex = '/{avsyoutube\s*.*?}/i';

		// Find all instances of plugin and put in $matches
		preg_match_all( $regex, $article->text, $matches );

		$this->_process( $article, $matches[0], $regex );
	}

	private function _process( $article, $matches, $regex ) {	
		foreach ( $matches as $match ) {
			$query = str_replace( '{avsyoutube', '', $match );
			$query = str_replace( '}', '', $query );
			$query = str_replace( '"', '', $query );
			$query = str_replace( "'", '', $query );
			$query = strip_tags( $query );
			$query = trim( $query );
			$query = explode( ' ', $query );
			$query = implode( '&', $query );
			
			$player = $this->_load( $query );
			$article->text = str_replace( $match, $player, $article->text );
		}

		// Removes the left tags
	   	$article->text = preg_replace( $regex, '', $article->text );	   
   }

   private function _load( $query ) {	
		parse_str( $query, $params );
		return AllVideoShareYouTubeHelper::renderGallery( $params );
	}

}
